==> pmercury-0.5.0.26-py3-none-any.whl: pmercury/utils/cert_constants.py <==


cert_versions = {
    '00': 'v1',
    '01': 'v2',
    '02': 'v3',
}

cert_attribute_types = {
    '00': 'id-at-objectClass',
    '01': 'id-at-aliasedEntryName',
    '02': 'id-at-knowldgeinformation',
    '03': 'id-at-commonName',
    '04': 'id-at-surname',
    '05': 'id-at-serialNumber',
    '06': 'id-at-countryName',
    '07': 'id-at-localityName',
    '08': 'id-at-stateOrProvinceName',
    '09': 'id-at-streetAddress',
    '0a': 'id-at-organizationName',
    '0b': 'id-at-organizationalUnitName',
    '0c': 'id-at-title',
    '0d': 'id-at-description',
    '0e': 'id-at-searchGuide',
    '0f': 'id-at-businessCategory',
    '10': 'id-at-postalAddress',
    '11': 'id-at-postalCode',
    '12': 'id-at-postOfficeBox',
    '13': 'id-at-physicalDeliveryOfficeName',
    '14': 'id-at-telephoneNumber',
    '15': 'id-at-telexNumber',
    '16': 'id-at-teletexTerminalIdentifier',
    '17': 'id-at-facsimileTelephoneNumber',
    '18': 'id-at-x121Address',
    '19': 'id-at-internationalISDNNumber',
    '1a': 'id-at-registeredAddress',
    '1b': 'id-at-destinationIndicator',
    '1c': 'id-at-preferredDeliveryMethod',
    '1d': 'id-at-presentationAddress',
    '1e': 'id-at-supportedApplicationContext',
    '1f': 'id-at-member',
    '20': 'id-at-owner',
    '21': 'id-at-roleOccupant',
    '22': 'id-at-seeAlso',
    '23': 'id-at-userPassword',
    '24': 'id-at-userCertificate',
    '25': 'id-at-cACertificate',
    '26': 'id-at-authorityRevocationList',
    '27': 'id-at-certificateRevocationList',
    '28': 'id-at-crossCertificatePair',
    '29': 'id-at-name',
    '2a': 'id-at-givenName',
    '2b': 'id-at-initials',
    '2c': 'id-at-generationQualifier',
    '2d': 'id-at-uniqueIdentifier',
    '2e': 'id-at-dnQualifier',
    '2f': 'id-at-enhancedSearchGuide',
    '30': 'id-at-protocolInformation',
    '31': 'id-at-distinguishedName',
    '32': 'id-at-uniqueMember',
    '33': 'id-at-houseIdentifier',
    '34': 'id-at-supportedAlgorithms',
    '35': 'id-at-deltaRevocationList',
    '3a': 'id-at-attributeCertificate',
    '41': 'id-at-pseudonym',
}

cert_extensions = {
    '01': 'id-ce-authorityKeyIdentifier-old',
    '02': 'id-ce-keyAttributes-old',
    '03': 'id-ce-certificatePolicies-old',
    '04': 'id-ce-keyUsageRestriction-old',
    '09': 'id-ce-subjectDirectoryAttributes',
    '0e': 'id-ce-subjectKeyIdentifier',
    '0f': 'id-ce-keyUsage',
    '10': 'id-ce-privateKeyUsagePeriod',
    '11': 'id-ce-subjectAltName',
    '12': 'id-ce-issuerAltName',
    '13': 'id-ce-basicConstraints',
    '14': 'id-ce-cRLNumber',
    '15': 'id-ce-reasonCode',
    '17': 'id-ce-instructionCode',
    '18': 'id-ce-invalidityDate',
    '1b': 'id-ce-deltaCRLIndicator',
    '1c': 'id-ce-issuingDistributionPoint',
    '1d': 'id-ce-certificateIssuer',
    '1e': 'id-ce-nameConstraints',
    '1f': 'id-ce-CRLDistributionPoints',
    '20': 'id-ce-certificatePolicies',
    '21': 'id-ce-policyMappings',
    '23': 'id-ce-authorityKeyIdentifier',
    '24': 'id-ce-policyConstraints',
    '25': 'id-ce-extKeyUsage',
    '2e': 'id-ce-freshestCRL',
    '36': 'id-ce-inhibitAnyPolicy',
}

cert_extensions_private = {
    '01': 'id-pe-authorityInfoAccess',
    '02': 'id-pe-biometricInfo',
    '03': 'id-pe-qcStatements',
    '0c': 'id-pe-logotype',
    '17': 'id-pe-noSecrecyAfforded',
}

oid_mapping = {
    '2b06010401d679020402': 'id-ce-SignedCertificateTimestampList'
}

cert_general_name_types = {
    0: 'otherName',
    1: 'rfc822Name',
    2: 'dNSName',
    3: 'x400Address',
    4: 'directoryName',
    5: 'ediPartyName',
    6: 'uniformResourceIdentifier',
    7: 'iPAddress',
    8: 'registeredID',
}

==> pmercury-0.5.2.44-py3-none-any.whl: pmercury/utils/cert_constants.py <==


cert_versions = {
    '00': 'v1',
    '01': 'v2',
    '02': 'v3',
}

cert_attribute_types = {
    '00': 'id-at-objectClass',
    '01': 'id-at-aliasedEntryName',
    '02': 'id-at-knowldgeinformation',
    '03': 'id-at-commonName',
    '04': 'id-at-surname',
    '05': 'id-at-serialNumber',
    '06': 'id-at-countryName',
    '07': 'id-at-localityName',
    '08': 'id-at-stateOrProvinceName',
    '09': 'id-at-streetAddress',
    '0a': 'id-at-organizationName',
    '0b': 'id-at-organizationalUnitName',
    '0c': 'id-at-title',
    '0d': 'id-at-description',
    '0e': 'id-at-searchGuide',
    '0f': 'id-at-businessCategory',
    '10': 'id-at-postalAddress',
    '11': 'id-at-postalCode',
    '12': 'id-at-postOfficeBox',
    '13': 'id-at-physicalDeliveryOfficeName',
    '14': 'id-at-telephoneNumber',
    '15': 'id-at-telexNumber',
    '16': 'id-at-teletexTerminalIdentifier',
    '17': 'id-at-facsimileTelephoneNumber',
    '18': 'id-at-x121Address',
    '19': 'id-at-internationalISDNNumber',
    '1a': 'id-at-registeredAddress',
    '1b': 'id-at-destinationIndicator',
    '1c': 'id-at-preferredDeliveryMethod',
    '1d': 'id-at-presentationAddress',
    '1e': 'id-at-supportedApplicationContext',
    '1f': 'id-at-member',
    '20': 'id-at-owner',
    '21': 'id-at-roleOccupant',
    '22': 'id-at-seeAlso',
    '23': 'id-at-userPassword',
    '24': 'id-at-userCertificate',
    '25': 'id-at-cACertificate',
    '26': 'id-at-authorityRevocationList',
    '27': 'id-at-certificateRevocationList',
    '28': 'id-at-crossCertificatePair',
    '29': 'id-at-name',
    '2a': 'id-at-givenName',
    '2b': 'id-at-initials',
    '2c': 'id-at-generationQualifier',
    '2d': 'id-at-uniqueIdentifier',
    '2e': 'id-at-dnQualifier',
    '2f': 'id-at-enhancedSearchGuide',
    '30': 'id-at-protocolInformation',
    '31': 'id-at-distinguishedName',
    '32': 'id-at-uniqueMember',
    '33': 'id-at-houseIdentifier',
    '34': 'id-at-supportedAlgorithms',
    '35': 'id-at-deltaRevocationList',
    '3a': 'id-at-attributeCertificate',
    '41': 'id-at-pseudonym',
}

cert_extensions = {
    '01': 'id-ce-authorityKeyIdentifier-old',
    '02': 'id-ce-keyAttributes-old',
    '03': 'id-ce-certificatePolicies-old',
    '04': 'id-ce-keyUsageRestriction-old',
    '09': 'id-ce-subjectDirectoryAttributes',
    '0e': 'id-ce-subjectKeyIdentifier',
    '0f': 'id-ce-keyUsage',
    '10': 'id-ce-privateKeyUsagePeriod',
    '11': 'id-ce-subjectAltName',
    '12': 'id-ce-issuerAltName',
    '13': 'id-ce-basicConstraints',
    '14': 'id-ce-cRLNumber',
    '15': 'id-ce-reasonCode',
    '17': 'id-ce-instructionCode',
    '18': 'id-ce-invalidityDate',
    '1b': 'id-ce-deltaCRLIndicator',
    '1c': 'id-ce-issuingDistributionPoint',
    '1d': 'id-ce-certificateIssuer',
    '1e': 'id-ce-nameConstraints',
    '1f': 'id-ce-CRLDistributionPoints',
    '20': 'id-ce-certificatePolicies',
    '21': 'id-ce-policyMappings',
    '23': 'id-ce-authorityKeyIdentifier',
    '24': 'id-ce-policyConstraints',
    '25': 'id-ce-extKeyUsage',
    '2e': 'id-ce-freshestCRL',
    '36': 'id-ce-inhibitAnyPolicy',
}

cert_extensions_private = {
    '01': 'id-pe-authorityInfoAccess',
    '02': 'id-pe-biometricInfo',
    '03': 'id-pe-qcStatements',
    '0c': 'id-pe-logotype',
    '17': 'id-pe-noSecrecyAfforded',
}

oid_mapping = {
    '2b06010401d679020402': 'id-ce-SignedCertificateTimestampList',
    '2a864886f70d01010b': 'sha256WithRSAEncryption'
}



cert_general_name_types = {
    0: 'otherName',
    1: 'rfc822Name',
    2: 'dNSName',
    3: 'x400Address',
    4: 'directoryName',
    5: 'ediPartyName',
    6: 'uniformResourceIdentifier',
    7: 'iPAddress',
    8: 'registeredID',
}
